schema

package
v0.0.0-...-5729b54 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 20, 2020 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Dayofweek

type Dayofweek string

type MediaTypes

type MediaTypes struct {
	ID          int         `gorm:"column:id;primary_key"`
	Name        null.String `gorm:"column:name"`
	PlayoutType null.String `gorm:"column:playoutType"`
}

func (*MediaTypes) TableName

func (m *MediaTypes) TableName() string

TableName sets the insert table name for this struct type

type Schedule

type Schedule struct {
	Blockend   time.Time `gorm:"column:blockend"`
	Blockstart time.Time `gorm:"column:blockstart"`
	Dayofweek  `gorm:"column:dayofweek"`
	ID         int    `gorm:"column:id;primary_key"`
	MediaType  int    `gorm:"column:media_type"`
	Name       string `gorm:"column:name"`
}

func (*Schedule) TableName

func (s *Schedule) TableName() string

TableName sets the insert table name for this struct type

type Series

type Series struct {
	ID   int         `gorm:"column:id;primary_key"`
	Name null.String `gorm:"column:name"`
	Path null.String `gorm:"column:path"`
}

func (*Series) TableName

func (s *Series) TableName() string

TableName sets the insert table name for this struct type

type SeriesBumpers

type SeriesBumpers struct {
	ID      int         `gorm:"column:id;primary_key"`
	Inpath  null.String `gorm:"column:inpath"`
	Outpath null.String `gorm:"column:outpath"`
	Series  int         `gorm:"column:series"`
}

func (*SeriesBumpers) TableName

func (s *SeriesBumpers) TableName() string

TableName sets the insert table name for this struct type

Jump to