Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MediaTypes ¶
type MediaTypes struct {
ID int `gorm:"column:id;primary_key"`
Name null.String `gorm:"column:name"`
PlayoutType null.String `gorm:"column:playoutType"`
}
func (*MediaTypes) TableName ¶
func (m *MediaTypes) TableName() string
TableName sets the insert table name for this struct type
type Schedule ¶
type Series ¶
type SeriesBumpers ¶
type SeriesBumpers struct {
ID int `gorm:"column:id;primary_key"`
Inpath null.String `gorm:"column:inpath"`
Outpath null.String `gorm:"column:outpath"`
Series int `gorm:"column:series"`
}
func (*SeriesBumpers) TableName ¶
func (s *SeriesBumpers) TableName() string
TableName sets the insert table name for this struct type
Click to show internal directories.
Click to hide internal directories.